==> flyyfluttersdk-1.0.0%2B1.tar.gz: lib/views/FlyyGiftCardsPage.dart <==
import 'dart:convert';

import 'package:app_settings/app_settings.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:fluttertoast/fluttertoast.dart';
import 'package:flyyfluttersdk/Flyy.dart';
import 'package:flyyfluttersdk/helpers/APIClient.dart';
import 'package:flyyfluttersdk/helpers/FlyyUtility.dart';
import 'package:flyyfluttersdk/model/FlyyGiftCard.dart';
import 'package:flyyfluttersdk/model/FlyyGiftCardData.dart';
import 'package:flyyfluttersdk/model/FlyyWalletCompleteData.dart';
import 'package:flyyfluttersdk/model/FlyyWalletModel.dart';
import 'package:flyyfluttersdk/views/FlyyBuyGiftCardDialog.dart';
import 'package:flyyfluttersdk/views/FlyyGiftCardDetailsPage.dart';

///Stateless widget
class FlyyGiftCardsPage extends StatelessWidget {
  FlyyWalletModel flyyWalletModel;
  FlyyWalletCompleteData flyyWalletCompleteData;

  FlyyGiftCardsPage(
      {Key key, @required this.flyyWalletCompleteData, this.flyyWalletModel})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return FlyyGiftCardsStateFulWidget(
      flyyWalletCompleteData: flyyWalletCompleteData,
      flyyWalletModel: flyyWalletModel,
    );
  }
}

///Stateful widget
class FlyyGiftCardsStateFulWidget extends StatefulWidget {
  FlyyWalletCompleteData flyyWalletCompleteData;
  FlyyWalletModel flyyWalletModel;

  FlyyGiftCardsStateFulWidget(
      {Key key, @required this.flyyWalletCompleteData, this.flyyWalletModel})
      : super(key: key);

  @override
  State<StatefulWidget> createState() {
    return new FlyyGiftCardsState();
  }
}

class FlyyGiftCardsState extends State<FlyyGiftCardsStateFulWidget> {
  FlyyGiftCard flyyGiftCard;
  String activeCurrencyLabel, activeCurrencyIconUrl;
  int activeCurrencyBalance;

  @override
  void initState() {
    super.initState();
    getBalanceValues();
  }

  getBalanceValues() {
    FlyyUtility.getActiveCurrencyBalance().then((balance) {
      setState(() {
        activeCurrencyBalance = balance;
      });
    });
    FlyyUtility.getActiveCurrencyLabel().then((label) {
      setState(() {
        activeCurrencyLabel = label;
      });
    });
    FlyyUtility.getActiveCurrencyIconUrl().then((iconUrl) {
      setState(() {
        activeCurrencyIconUrl = iconUrl;
      });
    });
  }

  FlyyWalletCompleteData flyyWalletCompleteData;
  FlyyWalletModel flyyWalletModel;

  ///Call fetch rewards and load UI when response is success.
  @override
  Widget build(BuildContext context) {
    flyyWalletModel = widget.flyyWalletModel;
    flyyWalletCompleteData = widget.flyyWalletCompleteData;
    return Scaffold(
      appBar: AppBar(
        bottomOpacity: 0.0,
        elevation: 0.0,
        leading: IconButton(
          icon: Icon(Icons.arrow_back, color: Colors.white),
          onPressed: () {
            if (Navigator.canPop(context)) {
              Navigator.of(context).pop();
            } else {
              SystemNavigator.pop();
            }
          },
        ),
        title: Text('Gift Cards'),
        actions: <Widget>[
          Container(
            height: 20,
            margin: const EdgeInsets.only(right: 10),
            padding: const EdgeInsets.all(5),
            child: Card(
              shape: RoundedRectangleBorder(
                borderRadius: BorderRadius.circular(15),
              ),
              color: Colors.white,
              child: Padding(
                padding: const EdgeInsets.all(5),
                child: Row(
                  mainAxisAlignment: MainAxisAlignment.center,
                  children: <Widget>[
                    activeCurrencyIconUrl != null &&
                            activeCurrencyIconUrl.isNotEmpty
                        ? Image.network(
                            activeCurrencyIconUrl,
                            height: 20,
                            width: 20,
                          )
                        : SizedBox.shrink(),
                    Padding(
                      padding: const EdgeInsets.only(left: 5),
                      child: Text(
                        FlyyUtility.setRewardText(
                            activeCurrencyBalance, activeCurrencyLabel),
                        style: TextStyle(fontSize: 12),
                      ),
                    ),
                  ],
                ),
              ),
            ),
          ),
        ],
        backgroundColor: Flyy.TOOLBAR_COLOR,
      ),
      body: makeNetworkCall(context),
    );
  }

  ///fetch data
  Widget makeNetworkCall(BuildContext context) {
    return FutureBuilder<bool>(
      future: FlyyUtility.checkIfInterentPresent(),
      builder: (BuildContext context, AsyncSnapshot response) {
        if (response != null && response.data != null && response.data) {
          // Internet Present Case
          return FutureBuilder<FlyyGiftCard>(
            future: fetchGiftCards(),
            builder: (BuildContext context, AsyncSnapshot response) {
              if (response.connectionState == ConnectionState.waiting) {
                return Center(child: CircularProgressIndicator());
              } else {
                if (response.hasData && response.data != null) {
                  flyyGiftCard = response.data;
                  return setGiftCardsUI(context, flyyGiftCard);
                } else if (response.hasError) {
                  return Center(child: Text("${response.error}"));
                }
              }
              return Center(child: CircularProgressIndicator());
            },
          );
        } else {
          // No-Internet Case
          return noInternetLayout(context);
        }
      },
    );
  }

  ///Set listview of gift cards list
  Widget setGiftCardsUI(BuildContext context, FlyyGiftCard flyyGiftCard) {
    return ListView.separated(
      separatorBuilder: (context, index) => Divider(
        color: FlyyUtility.parseColor("#D3D3D3"),
      ),
      itemBuilder: setGiftCardsListView,
      itemCount: flyyGiftCard.giftCardsList != null
          ? flyyGiftCard.giftCardsList.length
          : 0,
      scrollDirection: Axis.vertical,
      shrinkWrap: true,
    );
  }

  ///Custom list-view elements/
  Widget setGiftCardsListView(BuildContext context, int index) {
    FlyyGiftCardData giftCardData = flyyGiftCard.giftCardsList[index];
    return new Container(
      margin: const EdgeInsets.all(10),
      child: Row(
        mainAxisAlignment: MainAxisAlignment.spaceBetween,
        children: <Widget>[
          GestureDetector(
            onTap: () {
              Navigator.push(
                context,
                MaterialPageRoute(
                    builder: (context) => FlyyGiftCardDetailsPage(
                          flyyGiftCardData: giftCardData,
//                          flyyWalletCompleteData: widget.flyyWalletCompleteData,
//                          flyyWalletModel: widget.flyyWalletModel,
                        )),
              );
            },
            child: Row(children: <Widget>[
              ///gift card image
              Image(
                image: NetworkImage(giftCardData.imageUrl),
                fit: BoxFit.fill,
                width: 60,
                height: 35,
              ),

              ///gift card name and range
              Container(
                margin: const EdgeInsets.only(left: 5),
                child: Column(
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: <Widget>[
                    ///gift card name
                    Text(
                      giftCardData.name,
                      textAlign: TextAlign.left,
                      style: new TextStyle(
                          fontSize: 14,
                          color: FlyyUtility.parseColor('#544e4e')),
                    ),

                    ///gift card value
                    Padding(
                      padding: const EdgeInsets.only(top: 5),
                      child: Row(
                        children: <Widget>[
                          Text(
                            'Value: ₹',
                            style: TextStyle(
                                fontSize: 10,
                                color: FlyyUtility.parseColor('#373535')),
                          ),
                          Text(
                            giftCardData.value != null ? giftCardData.value : 0,
                            style: new TextStyle(
                                fontSize: 12,
                                color: FlyyUtility.parseColor('#544e4e')),
                          ),
                        ],
                      ),
                    ),
                  ],
                ),
              ),
            ]),
          ),

          ///coins layout
          GestureDetector(
            onTap: () {
              if (giftCardData.currencyReq <= activeCurrencyBalance) {
                showDialog(
                    context: context,
                    builder: (BuildContext context) => FlyyBuyGiftCardDialog(
                          flyyGiftCardData: giftCardData,
                          flyyWalletModel: widget.flyyWalletModel,
                          flyyWalletCompleteData: widget.flyyWalletCompleteData,
                        )).then((value) {
                  setState(() {
                    getBalanceValues();
                  });
                });
              } else {
                FlyyUtility.showToast(
                    context, "Not enough balance", ToastGravity.CENTER);
              }
            },
            child: Container(
              decoration: BoxDecoration(
                border: Border.all(
                  color: Flyy.TOOLBAR_COLOR,
                ),
                borderRadius: BorderRadius.circular(5.0),
              ),
              child: Padding(
                padding: const EdgeInsets.only(
                    left: 10, right: 10, top: 4, bottom: 4),
                child: Row(
                  children: <Widget>[
                    activeCurrencyIconUrl != null &&
                            activeCurrencyIconUrl.isNotEmpty
                        ? Image.network(
                            activeCurrencyIconUrl,
                            height: 20,
                            width: 20,
                          )
                        : SizedBox.shrink(),
                    Padding(
                      padding: const EdgeInsets.only(left: 5),
                      child: Text(
                        FlyyUtility.setRewardText(giftCardData.currencyReq,
                            "" /*activeCurrencyLabel*/),
                        style: TextStyle(
                            fontSize: 12,
                            color: FlyyUtility.parseColor('#544e4e')),
                      ),
                    ),
                  ],
                ),
              ),
            ),
          )
        ],
      ),
    );
  }

  ///no internet layout
  Widget noInternetLayout(BuildContext context) {
    return Container(
      margin: const EdgeInsets.all(20),
      child: Column(
        mainAxisAlignment: MainAxisAlignment.center,
        children: <Widget>[
          Image.network(
            "https://ghc.theflyy.com/assets/fs_assets/ic_no_internet.png",
            height: 80,
            width: 80,
          ),
          Padding(
            padding: const EdgeInsets.only(top: 10, bottom: 10),
            child: Text(
              "Couldn't connect to the internet. Please check your network.",
              textAlign: TextAlign.center,
              style: TextStyle(
                  fontSize: 15, color: FlyyUtility.parseColor('#575555')),
            ),
          ),
          Row(
            mainAxisAlignment: MainAxisAlignment.spaceEvenly,
            children: <Widget>[
              GestureDetector(
                onTap: () {
                  makeNetworkCall(context);
                },
                child: Row(
                  children: <Widget>[
                    Icon(
                      Icons.refresh,
                      size: 30,
                      color: FlyyUtility.parseColor('#717171'),
                    ),
                    Padding(
                      padding: const EdgeInsets.only(left: 5),
                      child: Text(
                        'Tap To Retry',
                        style: TextStyle(
                            fontSize: 14,
                            color: FlyyUtility.parseColor('#717171')),
                      ),
                    )
                  ],
                ),
              ),
              GestureDetector(
                onTap: () {
                  AppSettings.openAppSettings();
                },
                child: Row(
                  children: <Widget>[
                    Image.network(
                      "https://ghc.theflyy.com/assets/fs_assets/ic_settings.png",
                      height: 30,
                      width: 30,
                    ),
                    Padding(
                      padding: const EdgeInsets.only(left: 5),
                      child: Text(
                        'Go To Settings',
                        style: TextStyle(
                            fontSize: 14,
                            color: FlyyUtility.parseColor('#717171')),
                      ),
                    )
                  ],
                ),
              ),
            ],
          )
        ],
      ),
    );
  }
}

Future<FlyyGiftCard> fetchGiftCards() async {
  final response = await APIClient.getClient("gift_cards");
  if (response.statusCode == 200) {
    final responseJson = json.decode(response.body);

    return FlyyGiftCard.fromJson(responseJson);
  } else {
    throw Exception('Failed to load data for gift cards');
  }
}

==> flyyfluttersdk-1.0.1%2B1.tar.gz: lib/views/FlyyGiftCardsPage.dart <==
import 'dart:convert';

import 'package:app_settings/app_settings.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:fluttertoast/fluttertoast.dart';
import 'package:flyyfluttersdk/Flyy.dart';
import 'package:flyyfluttersdk/helpers/APIClient.dart';
import 'package:flyyfluttersdk/helpers/FlyyUtility.dart';
import 'package:flyyfluttersdk/model/FlyyGiftCard.dart';
import 'package:flyyfluttersdk/model/FlyyGiftCardData.dart';
import 'package:flyyfluttersdk/model/FlyyWalletCompleteData.dart';
import 'package:flyyfluttersdk/model/FlyyWalletModel.dart';
import 'package:flyyfluttersdk/views/FlyyBuyGiftCardDialog.dart';
import 'package:flyyfluttersdk/views/FlyyGiftCardDetailsPage.dart';

///Stateless widget
class FlyyGiftCardsPage extends StatelessWidget {
  FlyyWalletModel flyyWalletModel;
  FlyyWalletCompleteData flyyWalletCompleteData;

  FlyyGiftCardsPage(
      {Key key, @required this.flyyWalletCompleteData, this.flyyWalletModel})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return FlyyGiftCardsStateFulWidget(
      flyyWalletCompleteData: flyyWalletCompleteData,
      flyyWalletModel: flyyWalletModel,
    );
  }
}

///Stateful widget
class FlyyGiftCardsStateFulWidget extends StatefulWidget {
  FlyyWalletCompleteData flyyWalletCompleteData;
  FlyyWalletModel flyyWalletModel;

  FlyyGiftCardsStateFulWidget(
      {Key key, @required this.flyyWalletCompleteData, this.flyyWalletModel})
      : super(key: key);

  @override
  State<StatefulWidget> createState() {
    return new FlyyGiftCardsState();
  }
}

class FlyyGiftCardsState extends State<FlyyGiftCardsStateFulWidget> {
  FlyyGiftCard flyyGiftCard;
  String activeCurrencyLabel, activeCurrencyIconUrl;
  int activeCurrencyBalance;
  FlyyUtility flyyUtility;

  @override
  void initState() {
    super.initState();
    flyyUtility = new FlyyUtility();
    getBalanceValues();
  }

  getBalanceValues() {
    flyyUtility.getActiveCurrencyBalance().then((balance) {
      setState(() {
        activeCurrencyBalance = balance;
      });
    });
    flyyUtility.getActiveCurrencyLabel().then((label) {
      setState(() {
        activeCurrencyLabel = label;
      });
    });
    flyyUtility.getActiveCurrencyIconUrl().then((iconUrl) {
      setState(() {
        activeCurrencyIconUrl = iconUrl;
      });
    });
  }

  FlyyWalletCompleteData flyyWalletCompleteData;
  FlyyWalletModel flyyWalletModel;

  ///Call fetch rewards and load UI when response is success.
  @override
  Widget build(BuildContext context) {
    flyyWalletModel = widget.flyyWalletModel;
    flyyWalletCompleteData = widget.flyyWalletCompleteData;
    return Scaffold(
      appBar: AppBar(
        bottomOpacity: 0.0,
        elevation: 0.0,
        leading: IconButton(
          icon: Icon(Icons.arrow_back, color: Colors.white),
          onPressed: () {
            if (Navigator.canPop(context)) {
              Navigator.of(context).pop();
            } else {
              SystemNavigator.pop();
            }
          },
        ),
        title: Text('Gift Cards'),
        actions: <Widget>[
          Container(
            height: 20,
            margin: const EdgeInsets.only(right: 10),
            padding: const EdgeInsets.all(5),
            child: Card(
              shape: RoundedRectangleBorder(
                borderRadius: BorderRadius.circular(15),
              ),
              color: Colors.white,
              child: Padding(
                padding: const EdgeInsets.all(5),
                child: Row(
                  mainAxisAlignment: MainAxisAlignment.center,
                  children: <Widget>[
                    activeCurrencyIconUrl != null &&
                            activeCurrencyIconUrl.isNotEmpty
                        ? Image.network(
                            activeCurrencyIconUrl,
                            height: 20,
                            width: 20,
                          )
                        : SizedBox.shrink(),
                    Padding(
                      padding: const EdgeInsets.only(left: 5),
                      child: Text(
                        flyyUtility.setRewardText(
                            activeCurrencyBalance, activeCurrencyLabel),
                        style: TextStyle(fontSize: 12),
                      ),
                    ),
                  ],
                ),
              ),
            ),
          ),
        ],
        backgroundColor: Flyy.TOOLBAR_COLOR,
      ),
      body: makeNetworkCall(context),
    );
  }

  ///fetch data
  Widget makeNetworkCall(BuildContext context) {
    return FutureBuilder<bool>(
      future: FlyyUtility.checkIfInterentPresent(),
      builder: (BuildContext context, AsyncSnapshot response) {
        if (response != null && response.data != null && response.data) {
          // Internet Present Case
          return FutureBuilder<FlyyGiftCard>(
            future: fetchGiftCards(),
            builder: (BuildContext context, AsyncSnapshot response) {
              if (response.connectionState == ConnectionState.waiting) {
                return Center(child: CircularProgressIndicator());
              } else {
                if (response.hasData && response.data != null) {
                  flyyGiftCard = response.data;
                  return setGiftCardsUI(context, flyyGiftCard);
                } else if (response.hasError) {
                  return Center(child: Text("${response.error}"));
                }
              }
              return Center(child: CircularProgressIndicator());
            },
          );
        } else {
          // No-Internet Case
          return noInternetLayout(context);
        }
      },
    );
  }

  ///Set listview of gift cards list
  Widget setGiftCardsUI(BuildContext context, FlyyGiftCard flyyGiftCard) {
    return ListView.separated(
      separatorBuilder: (context, index) => Divider(
        color: FlyyUtility.parseColor("#D3D3D3"),
      ),
      itemBuilder: setGiftCardsListView,
      itemCount: flyyGiftCard.giftCardsList != null
          ? flyyGiftCard.giftCardsList.length
          : 0,
      scrollDirection: Axis.vertical,
      shrinkWrap: true,
    );
  }

  ///Custom list-view elements/
  Widget setGiftCardsListView(BuildContext context, int index) {
    FlyyGiftCardData giftCardData = flyyGiftCard.giftCardsList[index];
    return new Container(
      margin: const EdgeInsets.all(10),
      child: Row(
        mainAxisAlignment: MainAxisAlignment.spaceBetween,
        children: <Widget>[
          GestureDetector(
            onTap: () {
              Navigator.push(
                context,
                MaterialPageRoute(
                    builder: (context) => FlyyGiftCardDetailsPage(
                          flyyGiftCardData: giftCardData,
                          flyyWalletCompleteData: widget.flyyWalletCompleteData,
                          flyyWalletModel: widget.flyyWalletModel,
                        )),
              );
            },
            child: Row(children: <Widget>[
              ///gift card image
              Image(
                image: NetworkImage(giftCardData.imageUrl),
                fit: BoxFit.fill,
                width: 60,
                height: 35,
              ),

              ///gift card name and range
              Container(
                margin: const EdgeInsets.only(left: 5),
                child: Column(
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: <Widget>[
                    ///gift card name
                    Text(
                      giftCardData.name,
                      textAlign: TextAlign.left,
                      style: new TextStyle(
                          fontSize: 14,
                          color: FlyyUtility.parseColor('#544e4e')),
                    ),

                    ///gift card value
                    Padding(
                      padding: const EdgeInsets.only(top: 5),
                      child: Row(
                        children: <Widget>[
                          Text(
                            'Value: ₹',
                            style: TextStyle(
                                fontSize: 10,
                                color: FlyyUtility.parseColor('#373535')),
                          ),
                          Text(
                            giftCardData.value != null ? giftCardData.value : 0,
                            style: new TextStyle(
                                fontSize: 12,
                                color: FlyyUtility.parseColor('#544e4e')),
                          ),
                        ],
                      ),
                    ),
                  ],
                ),
              ),
            ]),
          ),

          ///coins layout
          GestureDetector(
            onTap: () {
              if (giftCardData.currencyReq <= activeCurrencyBalance) {
                showDialog(
                    context: context,
                    builder: (BuildContext context) => FlyyBuyGiftCardDialog(
                          flyyGiftCardData: giftCardData,
                          flyyWalletModel: widget.flyyWalletModel,
                          flyyWalletCompleteData: widget.flyyWalletCompleteData,
                        )).then((value) {
                  setState(() {
                    getBalanceValues();
                  });
                });
              } else {
                FlyyUtility.showToast(
                    context, "Not enough balance", ToastGravity.CENTER);
              }
            },
            child: Container(
              decoration: BoxDecoration(
                border: Border.all(
                  color: Flyy.TOOLBAR_COLOR,
                ),
                borderRadius: BorderRadius.circular(5.0),
              ),
              child: Padding(
                padding: const EdgeInsets.only(
                    left: 10, right: 10, top: 4, bottom: 4),
                child: Row(
                  children: <Widget>[
                    activeCurrencyIconUrl != null &&
                            activeCurrencyIconUrl.isNotEmpty
                        ? Image.network(
                            activeCurrencyIconUrl,
                            height: 20,
                            width: 20,
                          )
                        : SizedBox.shrink(),
                    Padding(
                      padding: const EdgeInsets.only(left: 5),
                      child: Text(
                        flyyUtility.setRewardText(giftCardData.currencyReq,
                            "" /*activeCurrencyLabel*/),
                        style: TextStyle(
                            fontSize: 12,
                            color: FlyyUtility.parseColor('#544e4e')),
                      ),
                    ),
                  ],
                ),
              ),
            ),
          )
        ],
      ),
    );
  }

  ///no internet layout
  Widget noInternetLayout(BuildContext context) {
    return Container(
      margin: const EdgeInsets.all(20),
      child: Column(
        mainAxisAlignment: MainAxisAlignment.center,
        children: <Widget>[
          Image.network(
            "https://ghc.theflyy.com/assets/fs_assets/ic_no_internet.png",
            height: 80,
            width: 80,
          ),
          Padding(
            padding: const EdgeInsets.only(top: 10, bottom: 10),
            child: Text(
              "Couldn't connect to the internet. Please check your network.",
              textAlign: TextAlign.center,
              style: TextStyle(
                  fontSize: 15, color: FlyyUtility.parseColor('#575555')),
            ),
          ),
          Row(
            mainAxisAlignment: MainAxisAlignment.spaceEvenly,
            children: <Widget>[
              GestureDetector(
                onTap: () {
                  makeNetworkCall(context);
                },
                child: Row(
                  children: <Widget>[
                    Icon(
                      Icons.refresh,
                      size: 30,
                      color: FlyyUtility.parseColor('#717171'),
                    ),
                    Padding(
                      padding: const EdgeInsets.only(left: 5),
                      child: Text(
                        'Tap To Retry',
                        style: TextStyle(
                            fontSize: 14,
                            color: FlyyUtility.parseColor('#717171')),
                      ),
                    )
                  ],
                ),
              ),
              GestureDetector(
                onTap: () {
                  AppSettings.openAppSettings();
                },
                child: Row(
                  children: <Widget>[
                    Image.network(
                      "https://ghc.theflyy.com/assets/fs_assets/ic_settings.png",
                      height: 30,
                      width: 30,
                    ),
                    Padding(
                      padding: const EdgeInsets.only(left: 5),
                      child: Text(
                        'Go To Settings',
                        style: TextStyle(
                            fontSize: 14,
                            color: FlyyUtility.parseColor('#717171')),
                      ),
                    )
                  ],
                ),
              ),
            ],
          )
        ],
      ),
    );
  }
}

Future<FlyyGiftCard> fetchGiftCards() async {
  APIClient apiClient = new APIClient();
  final response = await apiClient.getClient("gift_cards");
  if (response.statusCode == 200) {
    final responseJson = json.decode(response.body);

    return FlyyGiftCard.fromJson(responseJson);
  } else {
    throw Exception('Failed to load data for gift cards');
  }
}
